@@ -1,4 +1,5 @@
 import os
+from itertools import product
 from operator import itemgetter
 from typing import Dict, List, Union
 
@@ -82,37 +83,35 @@ def _check_correlation_threshold(
         scoring: str,
         n_jobs: int
 ) -> List[str]:
-    for var_a in feature_names:
-        for var_b in feature_names:
-            if (
-                    var_a != var_b
-                    and abs(x[feature_names].corr()[var_a][var_b]) >= corr_threshold
-            ):
-                if _calc_score(
-                        x,
-                        y,
-                        var_a,
-                        random_state,
-                        class_weight,
-                        cv,
-                        c,
-                        scoring,
-                        n_jobs,
-                ) > _calc_score(
+    iter = product(feature_names, feature_names)
+    for var_a, var_b in iter:
+        if (var_a != var_b) and (var_a in feature_names) and (var_b in feature_names) and abs(
+                x[feature_names].corr()[var_a][var_b]
+                ) >= corr_threshold:
+            if _calc_score(
                     x,
                     y,
-                    var_b,
+                    var_a,
                     random_state,
                     class_weight,
                     cv,
                     c,
                     scoring,
                     n_jobs,
-                ):
-                    feature_names.remove(var_b)
-                else:
-                    feature_names.remove(var_a)
-                break
+            ) > _calc_score(
+                x,
+                y,
+                var_b,
+                random_state,
+                class_weight,
+                cv,
+                c,
+                scoring,
+                n_jobs,
+            ):
+                feature_names.remove(var_b)
+            else:
+                feature_names.remove(var_a)
     return feature_names
 
 
@@ -218,6 +217,12 @@ def iv_feature_select(
         iv_threshold: float,
         max_vars: int,
         n_jobs: int,
+        corr_threshold: float,
+        random_state: int,
+        class_weight: str,
+        cv: int,
+        c: float,
+        scoring: str,
 ) -> List[str]:
     temp_res_dict = Parallel(n_jobs=n_jobs)(
         delayed(_calc_iv_dict)(x, y, feature) for feature in feature_names
@@ -225,8 +230,21 @@ def iv_feature_select(
     res_dict = {}
     for d in temp_res_dict:
         res_dict.update(d)
-    return [feature for feature in dict(sorted(res_dict.items(), key=itemgetter(1), reverse=True)) if
-            res_dict[feature] >= iv_threshold][:max_vars]
+
+    feature_names = [feature for feature in dict(sorted(res_dict.items(), key=itemgetter(1), reverse=True)) if
+                     res_dict[feature] >= iv_threshold][:max_vars]
+    feature_names = _check_correlation_threshold(
+        x, y,
+        feature_names=feature_names,
+        corr_threshold=corr_threshold,
+        random_state=random_state,
+        class_weight=class_weight,
+        cv=cv,
+        c=c,
+        scoring=scoring,
+        n_jobs=n_jobs
+    )
+    return feature_names
 
 
 def _check_pvalue(model: sm.Logit) -> List[int]:
